@@ -9,7 +9,7 @@
 ### AUTHOR: Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 mbeta <- function(order, shape1, shape2)
-    .External("actuar_do_dpq", "mbeta", order, shape1, shape2, FALSE)
+    .External(C_actuar_do_dpq, "mbeta", order, shape1, shape2, FALSE)
 
 levbeta <- function(limit, shape1, shape2, order = 1)
-    .External("actuar_do_dpq", "levbeta", limit, shape1, shape2, order, FALSE)
+    .External(C_actuar_do_dpq, "levbeta", limit, shape1, shape2, order, FALSE)
