@@ -11,19 +11,19 @@
 ### AUTHOR: Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 dgumbel <- function (x, alpha, scale, log = FALSE)
-    .External("actuar_do_dpq", "dgumbel", x, alpha, scale, log)
+    .External(C_actuar_do_dpq, "dgumbel", x, alpha, scale, log)
 
 pgumbel <- function(q, alpha, scale, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "pgumbel", q, alpha, scale, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "pgumbel", q, alpha, scale, lower.tail, log.p)
 
 qgumbel <- function(p, alpha, scale, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "qgumbel", p, alpha, scale, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "qgumbel", p, alpha, scale, lower.tail, log.p)
 
 rgumbel <- function(n, alpha, scale)
-    .External("actuar_do_random", "rgumbel", n, alpha, scale)
+    .External(C_actuar_do_random, "rgumbel", n, alpha, scale)
 
 mgumbel <- function(order, alpha, scale)
-    .External("actuar_do_dpq", "mgumbel", order, alpha, scale, FALSE)
+    .External(C_actuar_do_dpq, "mgumbel", order, alpha, scale, FALSE)
 
 mgfgumbel <- function(t, alpha, scale, log = FALSE)
-    .External("actuar_do_dpq", "mgfgumbel", t, alpha, scale, log)
+    .External(C_actuar_do_dpq, "mgfgumbel", t, alpha, scale, log)
