@@ -9,10 +9,10 @@
 ### AUTHORS: Christophe Dutang, Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 munif <- function(order, min = 0, max = 1)
-    .External("actuar_do_dpq", "munif", order, min, max, FALSE)
+    .External(C_actuar_do_dpq, "munif", order, min, max, FALSE)
 
 levunif <- function(limit, min = 0, max =1, order = 1)
-    .External("actuar_do_dpq", "levunif", limit, min, max, order, FALSE)
+    .External(C_actuar_do_dpq, "levunif", limit, min, max, order, FALSE)
 
 mgfunif <- function(t, min = 0, max = 1, log = FALSE)
-    .External("actuar_do_dpq", "mgfunif", t, min, max, log)
+    .External(C_actuar_do_dpq, "mgfunif", t, min, max, log)
