@@ -9,13 +9,13 @@
 ### AUTHOR: Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 dzmnbinom <- function (x, size, prob, p0, log = FALSE)
-    .External("actuar_do_dpq", "dzmnbinom", x, size, prob, p0, log)
+    .External(C_actuar_do_dpq, "dzmnbinom", x, size, prob, p0, log)
 
 pzmnbinom <- function(q, size, prob, p0, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "pzmnbinom", q, size, prob, p0, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "pzmnbinom", q, size, prob, p0, lower.tail, log.p)
 
 qzmnbinom <- function(p, size, prob, p0, lower.tail = TRUE, log.p = FALSE)
-    .External("actuar_do_dpq", "qzmnbinom", p, size, prob, p0, lower.tail, log.p)
+    .External(C_actuar_do_dpq, "qzmnbinom", p, size, prob, p0, lower.tail, log.p)
 
 rzmnbinom <- function(n, size, prob, p0)
-    .External("actuar_do_random", "rzmnbinom", n, size, prob, p0)
+    .External(C_actuar_do_random, "rzmnbinom", n, size, prob, p0)
